@@ -1,10 +1,10 @@
 """Support GRPC for Muffin Framework."""
 import asyncio
 import logging
-import typing as t
 from importlib import import_module
 from pathlib import Path
 from signal import SIGINT, SIGTERM
+from typing import List, Optional, Union
 
 from grpc_tools import protoc
 from muffin import Application
@@ -13,15 +13,15 @@ from pkg_resources import resource_filename  # type: ignore
 
 import grpc
 
-# Support python 3.7
+# Support py37
 try:
-    from functools import cached_property  # type: ignore
+    from cached_property import cached_property  # noqa
 except ImportError:
-    from cached_property import cached_property  # type: ignore
+    from functools import cached_property
 
 from .utils import _fix_imports, _generate_file, _is_newer, _parse_proto
 
-__version__ = "0.3.4"
+__version__ = "0.4.1"
 
 
 INCLUDE = resource_filename("grpc_tools", "_proto")
@@ -32,15 +32,16 @@ class Plugin(BasePlugin):
     """Start server, register endpoints, connect to channels."""
 
     name = "grpc"
-    defaults: t.Dict[str, t.Any] = {
+    defaults = {
+        "autobuild": True,
         "build_dir": None,
+        "default_channel": "localhost:50051",
+        "default_channel_options": {},
         "server_listen": "[::]:50051",
         "ssl_client": False,
         "ssl_client_params": None,
         "ssl_server": False,
         "ssl_server_params": None,
-        "default_channel": "localhost:50051",
-        "default_channel_options": {},
     }
     logger = logging.getLogger("muffin-grpc")
 
@@ -71,9 +72,9 @@ class Plugin(BasePlugin):
         @app.manage
         async def grpc_build():
             """Build registered proto files."""
-            for path in self.proto_files:
+            for path, build_dir in self.proto_files:
                 self.logger.warning(f"Build: {path}")
-                self.build_proto(path, build_dir=self.cfg.build_dir)
+                self.build_proto(path, build_dir=build_dir)
 
         # TODO: Proto specs
         # -----------------
@@ -100,18 +101,19 @@ class Plugin(BasePlugin):
 
     def add_proto(
         self,
-        path: t.Union[str, Path],
-        build_dir: t.Union[str, Path] = None,
-        build_package: str = None,
-        targets: t.List[Path] = None,
+        path: Union[str, Path],
+        build_dir: Optional[Union[str, Path]] = None,
+        build_package: Optional[str] = None,
+        targets: Optional[List[Path]] = None,
     ):
         """Register/build the given proto file."""
         path = Path(path).absolute()
-        self.proto_files.append(path)
         build_dir = Path(build_dir or self.cfg.build_dir or path.parent)
-        return self.build_proto(
-            path, build_dir=build_dir, build_package=build_package, targets=targets
-        )
+        self.proto_files.append((path, build_dir))
+        if self.cfg.autobuild:
+            return self.build_proto(
+                path, build_dir=build_dir, build_package=build_package, targets=targets
+            )
 
     def add_to_server(self, service_cls):
         """Register the given service class to the server."""
@@ -120,7 +122,7 @@ class Plugin(BasePlugin):
         register = getattr(proto_module, f"add_{ proto_cls.__name__ }_to_server")
         self.services.append((service_cls, register))
 
-    def channel(self, target: str = None, **options):
+    def channel(self, target: Optional[str] = None, **options):
         """Open a channel."""
         if self.cfg.ssl_client:
             return grpc.aio.secure_channel(
@@ -136,11 +138,11 @@ class Plugin(BasePlugin):
 
     def build_proto(
         self,
-        path: t.Union[str, Path],
-        build_dir: t.Union[str, Path] = None,
-        build_package: t.Union[str, bool] = None,
-        targets: t.List[Path] = None,
-    ) -> t.List[Path]:
+        path: Union[str, Path],
+        build_dir: Optional[Union[str, Path]] = None,
+        build_package: Optional[Union[str, bool]] = None,
+        targets: Optional[List[Path]] = None,
+    ) -> List[Path]:
         """Build the given proto."""
         path = Path(path)
         if not path.exists():
